<?php
/**
 * @file
 * Drush commands for search api denormalized entity
 */

/**
 * Implements hook_drush_command().
 */
function search_api_grouping_drush_command() {
  $items = array();

  $items['search-api-grouping-generate'] = array(
    'description' => 'Generate the permutations of the denormalized entities.',
    'examples' => array(
      'search-api-grouping-generate' => dt('Generate the permutations of the denormalized entities.'),
      'drush sapi-gg' => dt('Alias to generate the permutations of the denormalized entities.'),
    ),
    'arguments' => array(
      'index_id' => dt('The numeric ID or machine name of an index.'),
    ),
    'aliases' => array('sapi-gg'),
  );
  return $items;
}

/**
 * Generate the permutations of the denormalized entities.
 */
function drush_search_api_grouping_generate($index_id = NULL) {
  if (search_api_drush_static(__FUNCTION__)) {
    return;
  }

  $indexes = search_api_drush_get_index($index_id);
  if (empty($indexes)) {
    drush_log(dt('No indexes found', array()), 'warning');
    return;
  }

  foreach ($indexes as $index) {
    if ($index->datasource() instanceof SearchApiDenormalizedEntityDataSourceController) {
      drush_log(dt('!index: starting permutation gernerator.', array('!index' => $index->machine_name)), 'ok');

      $entity_type = $index->datasource()->getEntityType();

      // Load entities to deal with.
      $entities = entity_load($entity_type, FALSE);
      $index->datasource()->createPermutationItems($index, $entity_type, $entities);

      drush_log(dt('!index successfully prepared.', array('!index' => $index->machine_name)), 'ok');
    }
    else {
      drush_log(dt('!index has no denormalized datasource - skipped', array('!index' => $index->machine_name)), 'notice');
    }
  }
}
